aboutsummaryrefslogtreecommitdiff
path: root/object/parse_without_header.go
diff options
context:
space:
mode:
Diffstat (limited to 'object/parse_without_header.go')
-rw-r--r--object/parse_without_header.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/object/parse_without_header.go b/object/parse_without_header.go
index d8774b9a..c889cb40 100644
--- a/object/parse_without_header.go
+++ b/object/parse_without_header.go
@@ -11,10 +11,10 @@ import (
objecttype "codeberg.org/lindenii/furgit/object/type"
)
// ParseObjectWithoutHeader parses a typed object body.
//
//nolint:ireturn
-func ParseObjectWithoutHeader(ty objecttype.Type, body []byte, algo objectid.Algorithm) (Object, error) {
+func ParseWithoutHeader(ty objecttype.Type, body []byte, algo objectid.Algorithm) (Object, error) {
switch ty {
case objecttype.TypeBlob:
return blob.Parse(body)
@@ -11,10 +11,10 @@ import (
objecttype "codeberg.org/lindenii/furgit/object/type"
)
-// ParseObjectWithoutHeader parses a typed object body.
+// ParseWithoutHeader parses a typed object body.
//
//nolint:ireturn